%global pkgname digraphs

Name:           gap-pkg-%{pkgname}
Version:        0.12.1
Release:        2%{?dist}
Summary:        GAP package for digraphs and multidigraphs

License:        GPLv3+
URL:            https://gap-packages.github.io/Digraphs/
Source0:        https://github.com/gap-packages/Digraphs/releases/download/v%{version}/%{pkgname}-%{version}.tar.gz
# Fedora-only patch: unbundle bliss
Patch0:         %{name}-bliss.patch
# Fedora-only patch: use the popcount instruction if available
Patch1:         %{name}-popcount.patch

BuildRequires:  bliss-devel
BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gap-pkg-grape
BuildRequires:  gap-pkg-io
BuildRequires:  gap-pkg-nautytracesinterface
BuildRequires:  gap-pkg-orb
BuildRequires:  gcc-c++

Requires:       gap-core
Requires:       gap-pkg-io
Requires:       gap-pkg-orb

Recommends:     gap-pkg-grape
Recommends:     gap-pkg-nautytracesinterface

%description
The Digraphs package is a GAP package containing methods for graphs,
digraphs, and multidigraphs.

%prep
%setup -q -n %{pkgname}-%{version}
%patch0
%patch1

# Make sure the bundled bliss is not used
rm -fr src/bliss-*

# Do not force use of the popcnt instruction
sed -i 's/ -march=native -mpopcnt//' Makefile.in

%build
export LC_ALL=C.UTF-8
%configure --with-gaproot=%{_gap_dir} --disable-silent-rules LIBS=-lbliss
%make_build

# Build the documentation
mkdir ../pkg
ln -s ../%{pkgname}-%{version} ../pkg
gap -l "$PWD/..;%{_gap_dir}" makedoc.g
rm -fr ../pkg

%install
# make install doesn't put ANYTHING where it is supposed to go, so...
mkdir -p %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc
cp -a bin data gap tst VERSION* *.g %{buildroot}%{_gap_dir}/pkg/%{pkgname}
cp -p doc/*.{bib,css,html,js,lab,pdf,six,txt,xml} \
   %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc

%check
export LC_ALL=C.UTF-8
cd tst
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF 2>&1 | tee log
LoadPackage("digraphs");
Test("testinstall.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/attr.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/cliques.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/digraph.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/display.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/grahom.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/io.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/isomorph.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/oper.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/orbits.tst", rec( compareFunction := "uptowhitespace" ));
Test("standard/prop.tst", rec( compareFunction := "uptowhitespace" ));
EOF
grep -Fvq fail log
rm -f log
find %{buildroot}%{_gap_dir}/pkg/%{pkgname} -size 0 -delete

%files
%doc CHANGELOG.md README.md
%license GPL LICENSE
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Apr 28 2018 Jerry James <loganjerry@gmail.com> - 0.12.1-1
- New upstream version

* Sat Mar 17 2018 Jerry James <loganjerry@gmail.com> - 0.12.0-1
- New upstream version

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan  9 2018 Jerry James <loganjerry@gmail.com> - 0.11.0-2
- Recommend gap-pkg-nautytracesinterface

* Sat Nov 25 2017 Jerry James <loganjerry@gmail.com> - 0.11.0-1
- New upstream version

* Thu Aug  3 2017 Jerry James <loganjerry@gmail.com> - 0.10.0-1
- Initial RPM
